Package: blme
Version: 1.0-4
Date: 2015-06-13
Title: Bayesian Linear Mixed-Effects Models
Author: Vincent Dorie <vjd4@nyu.edu>
Maintainer: Vincent Dorie <vjd4@nyu.edu>
Description: Maximum a posteriori estimation for linear and generalized
             linear mixed-effects models in a Bayesian setting. Extends
             'lme4' by Douglas Bates, Martin Maechler, Ben Bolker, and Steve Walker.
Depends: R (>= 3.0-0), lme4 (>= 1.0-6)
Imports: methods, stats, utils
Suggests: testthat (>= 0.9-0)
License: GPL (>= 2)
URL: https://github.com/vdorie/blme
BugReports: https://github.com/vdorie/blme/issues
NeedsCompilation: no
Packaged: 2015-06-13 17:22:47 UTC; vdorie
Repository: CRAN
Date/Publication: 2015-06-14 01:21:14
Built: R 3.4.1; ; 2018-04-07 07:28:29 UTC; windows
