Package: blme
Version: 1.0-6
Date: 2024-09-06
Title: Bayesian Linear Mixed-Effects Models
Authors@R: c(
  person("Vincent", "Dorie", role = c("aut", "cre"), email = "vdorie@gmail.com", comment = c(ORCID = "0000-0002-9576-3064")),
  person("Douglas", "Bates", role = "ctb", comment = c("lme4 non-modular functions", ORCID = "0000-0001-8316-9503")),
  person("Martin", "Maechler", role = "ctb", comment = c("lme4 non-modular functions", ORCID = "0000-0002-8685-9910")),
  person("Ben", "Bolker", role = "ctb", comment = c("lme4 non-modular functions", ORCID = "0000-0002-2127-0443")),
  person("Steven", "Walker", role = "ctb", comment = c("lme4 non-modular functions", ORCID = "0000-0002-4394-9078")))
Depends: R (>= 3.0-0), lme4 (>= 1.0-6)
Imports: methods, stats, utils
Suggests: expint (>= 0.1-3), testthat
Description: Maximum a posteriori estimation for linear and generalized linear mixed-effects models in a Bayesian setting, implementing the methods of Chung, et al. (2013) <doi:10.1007/s11336-013-9328-2>. Extends package 'lme4' (Bates, Maechler, Bolker, and Walker (2015) <doi:10.18637/jss.v067.i01>).
License: GPL (>= 2)
URL: https://github.com/vdorie/blme
BugReports: https://github.com/vdorie/blme/issues
NeedsCompilation: no
Packaged: 2024-09-07 03:08:42 UTC; vdorie
Author: Vincent Dorie [aut, cre] (<https://orcid.org/0000-0002-9576-3064>),
  Douglas Bates [ctb] (lme4 non-modular functions,
    <https://orcid.org/0000-0001-8316-9503>),
  Martin Maechler [ctb] (lme4 non-modular functions,
    <https://orcid.org/0000-0002-8685-9910>),
  Ben Bolker [ctb] (lme4 non-modular functions,
    <https://orcid.org/0000-0002-2127-0443>),
  Steven Walker [ctb] (lme4 non-modular functions,
    <https://orcid.org/0000-0002-4394-9078>)
Maintainer: Vincent Dorie <vdorie@gmail.com>
Repository: CRAN
Date/Publication: 2024-09-07 13:20:02 UTC
Built: R 4.4.1; ; 2024-09-09 17:17:20 UTC; unix
