export(blmer, bglmer)

exportClasses(bmerMod, blmerMod, bglmerMod)

S3method(print, bmerMod)
S3method(print, summary.bmerMod)
S3method(summary, bmerMod)
S3method(summary, summary.bmerMod)
S3method(vcov, summary.bmerMod)
S3method(refit, bmerMod)

S3method(toString, bmerNormalDist)
S3method(toString, bmerPointDist)
S3method(toString, bmerWishartDist)
S3method(toString, bmerInvWishartDist)
S3method(toString, bmerGammaDist)
S3method(toString, bmerInvGammaDist)

importFrom(methods, is, isGeneric, new, representation, show)
importFrom(methods, setClass, setGeneric, setMethod)
importFrom(stats, gaussian, vcov)
importFrom(utils, data, getS3method)

importClassesFrom(lme4, merMod, lmerMod, glmerMod)
importFrom(lme4, lmer, glmer)
importFrom(lme4, lFormula, glFormula)
importFrom(lme4, lmerControl, glmerControl)
importFrom(lme4, mkMerMod)
importFrom(lme4, optimizeGlmer)
importFrom(lme4, mkLmerDevfun, mkGlmerDevfun, updateGlmerDevfun)
importFrom(lme4, isLMM, isGLMM, mkRespMod, GHrule, isREML)
importFrom(lme4, refit)